<!-- Based on Othneil Drew's Best README Template: https://github.com/othneildrew/Best-README-Template/ -->
<a name="readme-top"></a>


<!-- PROJECT SHIELDS -->
<!--
*** Markdown "reference style" links is used for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]


<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/isc-konstanz/sparcs">
    <img src="doc/_images/lories-logo-isc.png" alt="Lories Logo">
  </a>
  <h1 align="center">sparcs</h1>
  <p align="center">
    SPARCS is an open-source software package for <em><b>S</b>olar <b>P</b>rediction, <b>A</b>nalytics & <b>R</b>esource <b>C</b>ontrol <b>S</b>ystems</em> <br>made with lories, powered by ISC Konstanz e.V.
  </p>
</div>


<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li><a href="#about-the-project">About The Project</a></li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>


<!-- ABOUT THE PROJECT -->
## About The Project

This project utilizes the independent pvlib toolbox, originally developed in MATLAB at Sandia National Laboratories,
and can be found on GitHub "https://github.com/pvlib/pvlib-python".

More detailed information about the project will be added here in the future.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- GETTING STARTED -->
## Getting Started

More detailed information on how to get started will be added here in the future.


### Prerequisites

We strongly recommend using virtual environments for development.
Virtual environments make it trivial to switch between different versions of software.
This [Astropy Guide](http://astropy.readthedocs.org/en/latest/development/workflow/virtual_pythons.html)
is a good reference for virtual environments.


### Installation

- Optionally, clone the GitHub repository
   ```sh
   git clone -b stable https://github.com/isc-konstanz/sparcs.git sparcs
   ```
- Optionally, create or activate virtual environment
- Install Python package
   ```sh
   pip install sparcs
   ```

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- USAGE EXAMPLES -->
## Usage

More detailed information about how to use the package will be added here in the future.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- LICENSE -->
## License

Distributed under the LGPLv3 License. See [`LICENSE`](https://github.com/isc-konstanz/sparcs/blob/main/LICENSE) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- CONTACT -->
## Contact

![ISC logo](doc/_images/isc-logo-full.png)

The sparcs project was authored by [**ISC** Konstanz e.V.](https://isc-konstanz.de/)
(International Solar Energy Research Center).

To get in touch with the developers, please take a look at the [Contact](doc/contact.md) site.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/isc-konstanz/sparcs.svg?style=for-the-badge
[contributors-url]: https://github.com/isc-konstanz/sparcs/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/isc-konstanz/sparcs.svg?style=for-the-badge
[forks-url]: https://github.com/isc-konstanz/sparcs/network/members
[stars-shield]: https://img.shields.io/github/stars/isc-konstanz/sparcs.svg?style=for-the-badge
[stars-url]: https://github.com/isc-konstanz/sparcs/stargazers
[issues-shield]: https://img.shields.io/github/issues/isc-konstanz/sparcs.svg?style=for-the-badge
[issues-url]: https://github.com/isc-konstanz/sparcs/issues
[license-shield]: https://img.shields.io/github/license/isc-konstanz/sparcs.svg?style=for-the-badge
[license-url]: https://github.com/isc-konstanz/sparcs/blob/main/LICENSE
